/*******************************************************************************
* Copyright (C) 2005 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/
#ifndef __CIMUTILS_HPP__
#define __CIMUTILS_HPP__

#include <openwbem/OW_config.h>
#include <openwbem/OW_CIMFwd.hpp>
#include <openwbem/OW_String.hpp>
#include <openwbem/OW_CIMOMHandleIFC.hpp>
#include <openwbem/OW_CIMObjectPath.hpp>
#include <openwbem/OW_CIMInstance.hpp>

namespace OMC
{

class CIMUtils
{
public:

    static bool classIsDerivedFrom(
		const OpenWBEM::String& derived, 
		const OpenWBEM::String& super, 
        OpenWBEM::CIMOMHandleIFCRef lch, 
        const OpenWBEM::String& ns); 

	/**
	 * Get the specified string key value from the given
	 * object path.
	 * @param op The object path to get the string value from.
	 * @param propertyName The name of the property to get the
	 *		value for.
	 * @return A String object that contains the property value.
	 *		If the property doesn't exist or isn't a String
	 *		data type, the returned String object will be empty.
	 */
	static OpenWBEM::String getStringKey(
		const OpenWBEM::CIMObjectPath& op,
		const OpenWBEM::String& propertyName);

	/**
	 * Get the specified object path key value from the given
	 * object path.
	 * @param op The object path to get the key value from.
	 * @param propertyName The name of the property to get the
	 *		value for.
	 * @return A CIMObjectPath object that contains the property value.
	 *		If the property doesn't exist or isn't a String
	 *		data type, the returned CIMObjectPath will be NULL.
	 */
	static OpenWBEM::CIMObjectPath getObjectPathKey(
		const OpenWBEM::CIMObjectPath& op,
		const OpenWBEM::String& propertyName);

	/**
	 * Get the string value from the specified property of a given
	 * CIM_Instance object..
	 * @param inst	The instance to get the property from.
	 * @param propName The name of the property to get the value for.
	 * @param throwIfAbsent Throw an invalid parm if prop not there.
	 * @return A String object that contains the property value.
	 *		If the property doesn't exist or isn't a String
	 *		data type, the returned String object will be empty.
	 */
	static OpenWBEM::String getStringProp(
		const OpenWBEM::CIMInstance& inst,
		const OpenWBEM::String& propName, 
		bool throwIfAbsent=false);

	/**
	 * Get the boolean value from the specified property of a given
	 * CIM_Instance object..
	 * @param inst	The instance to get the property from.
	 * @param propName The name of the property to get the value for.
	 * @param throwIfAbsent Throw an invalid parm if prop not there.
	 * @return A boolean value that represents the property value.
	 *		If the property doesn't exist or isn't a bool, then
	 *		false will be returned.
	 */
	static bool getBoolProp(
		const OpenWBEM::CIMInstance& inst,
		const OpenWBEM::String& propName, 
		bool defaultValue=false,
		bool throwIfAbsent=false);
}; 

}	// End of namespace OMC

#endif	// __CIMUTILS_HPP__

